.. _vf2:

*************
VF2 Algorithm 
*************

Graph Matcher
-------------

.. currentmodule:: networkx

.. autosummary::
   :toctree: generated/
   
    GraphMatcher.__init__
    GraphMatcher.initialize
    GraphMatcher.is_isomorphic
    GraphMatcher.subgraph_is_isomorphic
    GraphMatcher.isomorphisms_iter
    GraphMatcher.subgraph_isomorphisms_iter
    GraphMatcher.candidate_pairs_iter
    GraphMatcher.match
    GraphMatcher.semantic_feasibility
    GraphMatcher.syntactic_feasibility


DiGraph Matcher
---------------

.. autosummary::
   :toctree: generated/

    DiGraphMatcher.__init__
    DiGraphMatcher.initialize
    DiGraphMatcher.is_isomorphic
    DiGraphMatcher.subgraph_is_isomorphic
    DiGraphMatcher.isomorphisms_iter
    DiGraphMatcher.subgraph_isomorphisms_iter
    DiGraphMatcher.candidate_pairs_iter
    DiGraphMatcher.match
    DiGraphMatcher.semantic_feasibility
    DiGraphMatcher.syntactic_feasibility

Weighted Graph Matcher
----------------------

.. autosummary::
   :toctree: generated/

    WeightedGraphMatcher.__init__
    WeightedGraphMatcher.initialize
    WeightedGraphMatcher.is_isomorphic
    WeightedGraphMatcher.subgraph_is_isomorphic
    WeightedGraphMatcher.isomorphisms_iter
    WeightedGraphMatcher.subgraph_isomorphisms_iter
    WeightedGraphMatcher.candidate_pairs_iter
    WeightedGraphMatcher.match
    WeightedGraphMatcher.semantic_feasibility
    WeightedGraphMatcher.syntactic_feasibility


Weighted DiGraph Matcher
------------------------

.. autosummary::
   :toctree: generated/

    WeightedDiGraphMatcher.__init__
    WeightedDiGraphMatcher.initialize
    WeightedDiGraphMatcher.is_isomorphic
    WeightedDiGraphMatcher.subgraph_is_isomorphic
    WeightedDiGraphMatcher.isomorphisms_iter
    WeightedDiGraphMatcher.subgraph_isomorphisms_iter
    WeightedDiGraphMatcher.candidate_pairs_iter
    WeightedDiGraphMatcher.match
    WeightedDiGraphMatcher.semantic_feasibility
    WeightedDiGraphMatcher.syntactic_feasibility

Weighted MultiGraph Matcher
---------------------------

.. autosummary::
   :toctree: generated/

    WeightedMultiGraphMatcher.__init__
    WeightedMultiGraphMatcher.initialize
    WeightedMultiGraphMatcher.is_isomorphic
    WeightedMultiGraphMatcher.subgraph_is_isomorphic
    WeightedMultiGraphMatcher.isomorphisms_iter
    WeightedMultiGraphMatcher.subgraph_isomorphisms_iter
    WeightedMultiGraphMatcher.candidate_pairs_iter
    WeightedMultiGraphMatcher.match
    WeightedMultiGraphMatcher.semantic_feasibility
    WeightedMultiGraphMatcher.syntactic_feasibility


Weighted MultiDiGraph Matcher
-----------------------------

.. autosummary::
   :toctree: generated/

    WeightedMultiDiGraphMatcher.__init__
    WeightedMultiDiGraphMatcher.initialize
    WeightedMultiDiGraphMatcher.is_isomorphic
    WeightedMultiDiGraphMatcher.subgraph_is_isomorphic
    WeightedMultiDiGraphMatcher.isomorphisms_iter
    WeightedMultiDiGraphMatcher.subgraph_isomorphisms_iter
    WeightedMultiDiGraphMatcher.candidate_pairs_iter
    WeightedMultiDiGraphMatcher.match
    WeightedMultiDiGraphMatcher.semantic_feasibility
    WeightedMultiDiGraphMatcher.syntactic_feasibility

